Formulator is an extensible framework that eases the creation and validation of web forms. Important links: * Subscribe to the Formulator mailing list, for general discussions and questions on Formulator usage. * If you're interested in the further development of Formulator, subscribe to the Formulator-dev list * Formulator SourceForge project page * Formulator CVS web * Check out Formulator from CVS anonymously like this:: cvs -z3 -d:pserver:anonymous@cvs.infrae.com:/cvs/infrae co Formulator Important hint: *Don't ever* use *field_<fieldname>*; anything prefixed with *field_* in REQUEST is a Formulator implementation detail. Instead, don't forget to validate the form, for instance using *validate_all_to_request()*. See the Formulator API help and Howto for more information. Forgetting to validate the form is the most frequently made Formulator mistake that I've encountered. Documentation: * Formulator HOWTO * Very nice slides about Formulator by Jens Quade (in German) * A Zopelabs recipe by Scott Burton on using Formulator with Zope Page Templates * Howto on using Formulator with Zope Page Templates by Beno Some less important links: * Formulator on Freshmeat * Formulator project page on Advogato